@@ -300,9 +300,9 @@ test_set (Test *test,
 
 	g_signal_connect (test->config, "changed", G_CALLBACK (on_config_changed), &changed);
 
-	realm_ini_config_set (test->config, "section", "1", "the number one");
-	realm_ini_config_set (test->config, "section", "3", NULL);
-	realm_ini_config_set (test->config, "section", "4", "four");
+	realm_ini_config_set (test->config, "section", "1", "the number one", NULL);
+	realm_ini_config_set (test->config, "section", "3", NULL,
+	                      "4", "four", NULL);
 
 	g_assert (changed == TRUE);
 
@@ -321,7 +321,7 @@ test_set_middle (Test *test,
 
 	realm_ini_config_read_string (test->config, data);
 
-	realm_ini_config_set (test->config, "section", "3", "three");
+	realm_ini_config_set (test->config, "section", "3", "three", NULL);
 
 	output = realm_ini_config_write_string (test->config);
 	g_assert_cmpstr (check, ==, output);
@@ -337,13 +337,25 @@ test_set_and_get (Test *test,
 
 	realm_ini_config_read_string (test->config, data);
 
-	realm_ini_config_set (test->config, "section", "3", "three");
+	realm_ini_config_set (test->config, "section", "3", "three", NULL);
 
 	output = realm_ini_config_get (test->config, "section", "3");
 	g_assert_cmpstr (output, ==, "three");
 	g_free (output);
 }
 
+static void
+test_have (Test *test,
+          gconstpointer unused)
+{
+	const gchar *data = "[section]\n\t1= one\r\n2=two\n3=three";
+	realm_ini_config_read_string (test->config, data);
+
+	g_assert_cmpint (realm_ini_config_have (test->config, "section", "1"), ==, TRUE);
+	g_assert_cmpint (realm_ini_config_have (test->config, "section", "not there"), ==, FALSE);
+	g_assert_cmpint (realm_ini_config_have (test->config, "invalid", "2"), ==, FALSE);
+}
+
 static void
 test_set_section (Test *test,
                   gconstpointer unused)
@@ -354,8 +366,8 @@ test_set_section (Test *test,
 
 	realm_ini_config_read_string (test->config, data);
 
-	realm_ini_config_set (test->config, "happy", "4", "four");
-	realm_ini_config_set (test->config, "nope", "6", NULL);
+	realm_ini_config_set (test->config, "happy", "4", "four", NULL);
+	realm_ini_config_set (test->config, "nope", "6", NULL, NULL);
 
 	output = realm_ini_config_write_string (test->config);
 	g_assert_cmpstr (check, ==, output);
@@ -390,6 +402,20 @@ test_set_all (Test *test,
 	g_free (output);
 }
 
+static void
+test_get_sections (Test *test,
+                   gconstpointer unused)
+{
+	const gchar *data = "[section]\n\t1= one\r\n2=two\n3=three\n[section2]\n[three]";
+	gchar **sections;
+
+	realm_ini_config_read_string (test->config, data);
+	sections = realm_ini_config_get_sections (test->config);
+	g_assert (sections != NULL);
+	g_assert_cmpint (g_strv_length (sections), ==, 3);
+	g_strfreev (sections);
+}
+
 static void
 test_have_section (Test *test,
                    gconstpointer unused)
@@ -619,11 +645,50 @@ test_change_list_null_remove (Test *test,
 	g_free (output);
 }
 
+static void
+test_get_boolean (void)
+{
+	RealmIniConfig *config;
+
+	config = realm_ini_config_new (0);
+
+	realm_ini_config_read_string (config, "[section]\nboolean = true");
+	g_assert_cmpint (TRUE, ==, realm_ini_config_get_boolean (config, "section", "boolean", FALSE));
+
+	realm_ini_config_read_string (config, "[section]\nboolean = FalSE");
+	g_assert_cmpint (FALSE, ==, realm_ini_config_get_boolean (config, "section", "boolean", TRUE));
+
+	realm_ini_config_read_string (config, "[section]\nboolean = false");
+	g_assert_cmpint (FALSE, ==, realm_ini_config_get_boolean (config, "section", "boolean", TRUE));
+
+	realm_ini_config_read_string (config, "[section]\nboolean = false");
+	g_assert_cmpint (TRUE, ==, realm_ini_config_get_boolean (config, "section", "non-existant", TRUE));
+
+	realm_ini_config_read_string (config, "[section]\nboolean = false");
+	g_assert_cmpint (TRUE, ==, realm_ini_config_get_boolean (config, "section", "non-existant", TRUE));
+
+	realm_ini_config_read_string (config, "[section]\nboolean = yes");
+	g_assert_cmpint (TRUE, ==, realm_ini_config_get_boolean (config, "section", "boolean", TRUE));
+
+	realm_ini_config_read_string (config, "[section]\nboolean = no");
+	g_assert_cmpint (FALSE, ==, realm_ini_config_get_boolean (config, "section", "boolean", FALSE));
+
+	realm_ini_config_read_string (config, "[section]\nboolean = 1");
+	g_assert_cmpint (TRUE, ==, realm_ini_config_get_boolean (config, "section", "boolean", TRUE));
+
+	realm_ini_config_read_string (config, "[section]\nboolean = 0");
+	g_assert_cmpint (FALSE, ==, realm_ini_config_get_boolean (config, "section", "boolean", FALSE));
+
+	g_object_unref (config);
+}
+
 int
 main (int argc,
       char **argv)
 {
+#if !GLIB_CHECK_VERSION(2, 36, 0)
 	g_type_init ();
+#endif
 	g_test_init (&argc, &argv, NULL);
 	g_set_prgname ("test-ini-config");
 
@@ -638,12 +703,15 @@ main (int argc,
 	g_test_add ("/realmd/ini-config/write-file", Test, NULL, setup, test_write_file, teardown);
 	g_test_add ("/realmd/ini-config/write-empty-no-create", Test, NULL, setup, test_write_empty_no_create, teardown);
 
+	g_test_add ("/realmd/ini-config/have", Test, NULL, setup, test_have, teardown);
+
 	g_test_add ("/realmd/ini-config/set", Test, NULL, setup, test_set, teardown);
 	g_test_add ("/realmd/ini-config/set-middle", Test, NULL, setup, test_set_middle, teardown);
 	g_test_add ("/realmd/ini-config/set-and-get", Test, NULL, setup, test_set_and_get, teardown);
 	g_test_add ("/realmd/ini-config/set-section", Test, NULL, setup, test_set_section, teardown);
 	g_test_add ("/realmd/ini-config/set-all", Test, NULL, setup, test_set_all, teardown);
 
+	g_test_add ("/realmd/ini-config/get-sections", Test, NULL, setup, test_get_sections, teardown);
 	g_test_add ("/realmd/ini-config/have-section", Test, NULL, setup, test_have_section, teardown);
 	g_test_add ("/realmd/ini-config/remove-section-first", Test, NULL, setup, test_remove_section_first, teardown);
 	g_test_add ("/realmd/ini-config/remove-section-middle", Test, NULL, setup, test_remove_section_middle, teardown);
@@ -661,5 +729,7 @@ main (int argc,
 	g_test_add ("/realmd/ini-config/change-list-null-add", Test, NULL, setup, test_change_list_null_add, teardown);
 	g_test_add ("/realmd/ini-config/change-list-null-remove", Test, NULL, setup, test_change_list_null_remove, teardown);
 
+	g_test_add_func ("/realmd/ini-config/get-boolean", test_get_boolean);
+
 	return g_test_run ();
 }
